@@ -1,7 +1,7 @@
 package Perinci::Result::Format;
 
-our $DATE = '2015-11-04'; # DATE
-our $VERSION = '0.44'; # VERSION
+our $DATE = '2015-11-29'; # DATE
+our $VERSION = '0.45'; # VERSION
 
 use 5.010001;
 use strict;
@@ -108,10 +108,13 @@ my $format_text = sub {
     if ($res->[0] =~ /\A2../) {
         $r = $res->[2];
         my $rfo = $res->[3]{format_options} // {};
+        my $tff = $res->[3]{'table.fields'};
         if ($rfo->{$format}) {
             $opts = $rfo->{$format};
         } elsif ($rfo->{any}) {
             $opts = $rfo->{any};
+        } elsif ($tff) {
+            $opts = {table_column_orders=>[$tff]};
         }
     } else {
         $r = $res;
@@ -191,7 +194,7 @@ Perinci::Result::Format - Format envelope result
 
 =head1 VERSION
 
-This document describes version 0.44 of Perinci::Result::Format (from Perl distribution Perinci-Result-Format), released on 2015-11-04.
+This document describes version 0.45 of Perinci::Result::Format (from Perl distribution Perinci-Result-Format), released on 2015-11-29.
 
 =head1 SYNOPSIS
 
@@ -326,7 +329,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Re
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Perinci-Result-Format>.
+Source repository is at L<https://github.com/sharyanto/perl-Perinci-Result-Format>.
 
 =head1 BUGS
 
